@@ -97,7 +97,7 @@ Usage::
     list_resource_data_sync_paginator: ListResourceDataSyncPaginator = client.get_paginator("list_resource_data_sync")
     ```
 """
-from mypy_boto3_ssm.client import SSMClient as Client, SSMClient
+from mypy_boto3_ssm.client import SSMClient, SSMClient as Client
 from mypy_boto3_ssm.paginator import (
     DescribeActivationsPaginator,
     DescribeAssociationExecutionTargetsPaginator,
